@@ -55,6 +55,11 @@ def subscribe(request):
             else:
                 client_ip = request.META.get('REMOTE_ADDR')
 
+            if email := form.cleaned_data['email']:
+                user = request.user
+                user.email = email
+                user.save()
+
             sub = Subscription.create_from_token(
                     token,
                     plan,
